==========================================
Sample neutron-dynamic-routing Policy File
==========================================

The following is a sample neutron-dynamic-routing policy file for adaptation
and use.

The sample policy can also be viewed in :download:`file form
</_static/neutron-dynamic-routing.policy.yaml.sample>`.

.. important::

   The sample policy file is auto-generated from neutron-dynamic-routing when
   this documentation is built. You must ensure your version of
   neutron-dynamic-routing matches the version of this documentation.

.. literalinclude:: /_static/neutron-dynamic-routing.policy.yaml.sample
